@@ -93,7 +93,9 @@ impl Row {
     pub fn subset(&self, indices: &[usize]) -> Row {
         let mut subfields = vec![];
         for i in indices {
-            subfields.push(self.fields.get(*i).unwrap().clone());
+            if let Some(field) = self.fields.get(*i) {
+                subfields.push(field.clone());
+            }
         }
         Row {
             record_num: self.record_num,
@@ -300,6 +302,16 @@ impl CsvLensReader {
         let res = self.internal.lock().unwrap().pos_table.clone();
         res
     }
+
+    #[cfg(test)]
+    pub fn wait_internal(&self) {
+        loop {
+            if self.internal.lock().unwrap().done {
+                break;
+            }
+            thread::sleep(time::Duration::from_millis(100));
+        }
+    }
 }
 
 #[derive(Debug, Clone, PartialEq)]
@@ -388,8 +400,6 @@ impl ReaderInternalState {
 
 #[cfg(test)]
 mod tests {
-    use core::time;
-
     use super::*;
 
     impl Row {
@@ -401,17 +411,6 @@ mod tests {
         }
     }
 
-    impl CsvLensReader {
-        fn wait_internal(&self) {
-            loop {
-                if self.internal.lock().unwrap().done {
-                    break;
-                }
-                thread::sleep(time::Duration::from_millis(100));
-            }
-        }
-    }
-
     #[test]
     fn test_cities_get_rows() {
         let config = Arc::new(CsvConfig::new("tests/data/cities.csv", b',', false));
