@@ -8,6 +8,7 @@ use crate::view::Header;
 use crate::wrap;
 use ratatui::buffer::Buffer;
 use ratatui::layout::Rect;
+use ratatui::prelude::Position;
 use ratatui::style::{Color, Modifier, Style};
 use ratatui::symbols::line;
 use ratatui::text::{Line, Span};
@@ -19,6 +20,7 @@ use tui_input::Input;
 use std::cmp::{max, min};
 use std::collections::HashMap;
 use std::sync::Arc;
+use std::time::Duration;
 
 const NUM_SPACES_AFTER_LINE_NUMBER: u16 = 2;
 const NUM_SPACES_BETWEEN_COLUMNS: u16 = 4;
@@ -291,8 +293,9 @@ impl<'a> CsvTable<'a> {
         line_number_block.render(line_number_area, buf);
 
         // Intersection with header separator
-        buf.get_mut(section_width - 1, y_first_record - 1)
-            .set_symbol(line::HORIZONTAL_DOWN);
+        if let Some(cell) = buf.cell_mut(Position::new(section_width - 1, y_first_record - 1)) {
+            cell.set_symbol(line::HORIZONTAL_DOWN);
+        }
 
         // Status separator at the bottom (rendered here first for the interesection)
         let block = Block::default()
@@ -302,26 +305,39 @@ impl<'a> CsvTable<'a> {
         block.render(status_separator_area, buf);
 
         // Intersection with bottom separator
-        buf.get_mut(section_width - 1, y_first_record + area.height)
-            .set_symbol(line::HORIZONTAL_UP);
+        if let Some(cell) = buf.cell_mut(Position::new(
+            section_width - 1,
+            y_first_record + area.height,
+        )) {
+            cell.set_symbol(line::HORIZONTAL_UP);
+        }
 
         // Vertical line after last rendered column
         // TODO: refactor
         let col_ending_pos_x = state.col_ending_pos_x;
         if !state.has_more_cols_to_show() && col_ending_pos_x < area.right() {
-            buf.get_mut(col_ending_pos_x, y_first_record.saturating_sub(1))
-                .set_style(Style::default().fg(Color::Rgb(64, 64, 64)))
-                .set_symbol(line::HORIZONTAL_DOWN);
-
-            for y in y_first_record..y_first_record + area.height {
-                buf.get_mut(col_ending_pos_x, y)
-                    .set_style(Style::default().fg(Color::Rgb(64, 64, 64)))
-                    .set_symbol(line::VERTICAL);
+            if let Some(cell) = buf.cell_mut(Position::new(
+                col_ending_pos_x,
+                y_first_record.saturating_sub(1),
+            )) {
+                cell.set_style(Style::default().fg(Color::Rgb(64, 64, 64)))
+                    .set_symbol(line::HORIZONTAL_DOWN);
             }
 
-            buf.get_mut(col_ending_pos_x, y_first_record + area.height)
-                .set_style(Style::default().fg(Color::Rgb(64, 64, 64)))
-                .set_symbol(line::HORIZONTAL_UP);
+            for y in y_first_record..y_first_record + area.height {
+                if let Some(cell) = buf.cell_mut(Position::new(col_ending_pos_x, y)) {
+                    cell.set_style(Style::default().fg(Color::Rgb(64, 64, 64)))
+                        .set_symbol(line::VERTICAL);
+                }
+            }
+
+            if let Some(cell) = buf.cell_mut(Position::new(
+                col_ending_pos_x,
+                y_first_record + area.height,
+            )) {
+                cell.set_style(Style::default().fg(Color::Rgb(64, 64, 64)))
+                    .set_symbol(line::HORIZONTAL_UP);
+            }
         }
     }
 
@@ -744,7 +760,7 @@ impl<'a> CsvTable<'a> {
     }
 }
 
-impl<'a> StatefulWidget for CsvTable<'a> {
+impl StatefulWidget for CsvTable<'_> {
     type State = CsvTableState;
 
     fn render(self, area: Rect, buf: &mut Buffer, state: &mut Self::State) {
@@ -1037,27 +1053,42 @@ struct BordersState {
 }
 
 pub struct DebugStats {
+    show_stats: bool,
     rows_view_stats: Option<crate::view::PerfStats>,
-    finder_elapsed: Option<f64>,
+    finder_elapsed: Option<Duration>,
+    render_elapsed: Option<Duration>,
 }
 
 impl DebugStats {
     pub fn new() -> Self {
         DebugStats {
+            show_stats: false,
             rows_view_stats: None,
             finder_elapsed: None,
+            render_elapsed: None,
         }
     }
 
+    pub fn show_stats(&mut self, show: bool) {
+        self.show_stats = show;
+    }
+
     pub fn rows_view_perf(&mut self, stats: Option<crate::view::PerfStats>) {
         self.rows_view_stats = stats;
     }
 
-    pub fn finder_elapsed(&mut self, elapsed: Option<u128>) {
-        self.finder_elapsed = elapsed.map(|e| e as f64 / 1000.0);
+    pub fn finder_elapsed(&mut self, elapsed: Option<Duration>) {
+        self.finder_elapsed = elapsed;
+    }
+
+    pub fn render_elapsed(&mut self, elapsed: Option<Duration>) {
+        self.render_elapsed = elapsed;
     }
 
     pub fn status_line(&self) -> Option<String> {
+        if !self.show_stats {
+            return None;
+        }
         let mut line = "[".to_string();
         if let Some(stats) = &self.rows_view_stats {
             line += format!(
@@ -1076,14 +1107,13 @@ impl DebugStats {
             .as_str();
         }
         if let Some(elapsed) = self.finder_elapsed {
-            line += format!(" finder:{elapsed}ms").as_str();
+            line += format!(" finder:{:.3}ms", elapsed.as_micros() as f64 / 1000.0).as_str();
+        }
+        if let Some(elapsed) = self.render_elapsed {
+            line += format!(" render:{:.3}ms", elapsed.as_micros() as f64 / 1000.0).as_str();
         }
         line += "]";
-        if line == "[]" {
-            None
-        } else {
-            Some(line)
-        }
+        Some(line)
     }
 }
 
